@@ -1,7 +1,5 @@
 package threads::posix;
-{
-  $threads::posix::VERSION = '0.002';
-}
+$threads::posix::VERSION = '0.003';
 use strict;
 use warnings;
 
@@ -9,26 +7,38 @@ use XSLoader;
 
 XSLoader::load(__PACKAGE__, __PACKAGE__->VERSION);
 
-use parent 'threads';
+use base 'threads';
+
+sub import {
+	my ($class, @args) = @_;
+	if (@args && $args[0] eq '-global') {
+		no warnings 'redefine';
+		*threads::kill = \&kill;
+		*threads::cancel = \&cancel;
+	}
+}
 
 1;
 
 #ABSTRACT: more POSIX correct threads
 
-
+__END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 threads::posix - more POSIX correct threads
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
+ use threads::posix;
  my $thread = thread::posix->create(sub { ... });
  $thread->kill(SIGALRM);
 
@@ -36,6 +46,8 @@ version 0.002
 
 This module extends L<threads> to provide behaviors that are more conformant to what POSIX prescribes. You should realize that this doesn't in any way change the threads themselves, just how you intereract with them. Everything not described here should work exactly the same as in threads.pm.
 
+If this module is used with the -global option it will monkey-patch threads.pm.
+
 =head1 METHODS
 
 =head2 kill
@@ -63,7 +75,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
